MQR
---
This library is a python toolkit for manufacturing and design statistics.

Installation
------------
`pip install mqrpy`

Import the package using:<br>
`import mqr`

Documentation
-------------
The documentation, including a user guide and API reference is at https://nklsxn.github.io/mqr/latest/.

A set of detailed examples is available in the repository https://github.com/nklsxn/mqrpy-guide.

License
-------
This package is provided under the BSD License (3-clause).

Credit
------
Copyright 2024-2025 Nikolas Crossan and Kevin Otto

Supported by the University of Melbourne<br>
Department of Mechanical Engineering
